| Title: | Analyse and Visualise Multi Electrode Array Burst Data |
|---|---|
| Description: | Analyse and visualise multi electrode array data at the single electrode and whole well level, downstream of 'AxIS Navigator 3.6.2 Software' processing. Compare bursting parameters between time intervals and recordings using the bar chart visualisation functions. Compatible with 12- and 24- well plates. |
| Authors: | Emily Gordon [aut, cre] |
| Maintainer: | Emily Gordon <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.1.0 |
| Built: | 2026-06-09 06:35:31 UTC |
| Source: | https://github.com/egordon2/mea-analysis-package |
This function reads in, filters, and reformats electrode burst csv files produced by the axis navigator tool (Axion Biosystems) for use in analysis. This function filters the data to only contain information relating to single electrodes and burst characteristics. It also adds a 'Recording_identifier' column to enable other MEAanalysis functions to calculate burst parameters for a specific recording, as well as a column to identify the well a burst was recorded in.
create_electrode_dataset(data_path, recording_identifier)create_electrode_dataset(data_path, recording_identifier)
data_path |
Include path to electrode burst dataset csv or excel file produced by the axis navigator tool. This path should be written within quotation marks and with respect to the current working directory. |
recording_identifier |
Include a unique identifier for the MEA recording being loaded. This identifier will be added to the 'Recording_identifier' column and be used by other MEAanalysis functions to filter the data and calculate burst parameters. |
A reformatted and filtered electrode burst list for use in analysis.
output_electrode_burst <- create_electrode_dataset( data_path = system.file("extdata", "input_electrode_burst.csv", package = "MEAanalysis"), recording_identifier = "burst_recording_1")output_electrode_burst <- create_electrode_dataset( data_path = system.file("extdata", "input_electrode_burst.csv", package = "MEAanalysis"), recording_identifier = "burst_recording_1")
This function reads in, filters, and reformats neural metric csv files produced by the axis navigator neural metric tool (Axion Biosystems) for use in synchrony index analysis.
create_synchrony_dataset(data_path, heatmap_condition)create_synchrony_dataset(data_path, heatmap_condition)
data_path |
Include path to neural metric dataset csv or excel file produced by the axis navigator neural metric tool. This path should be written within quotation marks and with respect to the current working directory. |
heatmap_condition |
Include a unique identifier for this neuralMetric dataset's experimental condition, this argument will be used by the MEA_heatmap function to group data. |
A reformatted and filtered neural metric dataset for use in synchrony index analysis.
output_neuralMetric <- create_synchrony_dataset( data_path = system.file("extdata", "input_neuralMetric.csv", package = "MEAanalysis"), heatmap_condition = "SI_condition_1")output_neuralMetric <- create_synchrony_dataset( data_path = system.file("extdata", "input_neuralMetric.csv", package = "MEAanalysis"), heatmap_condition = "SI_condition_1")
Function reads in electrode burst list data and creates new columns with the mean, SD, and SEM burst duration recorded by single electrodes (within the specified time interval and recording).
electrode_burst_duration( data = output_table, time_lower_bound = 0, time_upper_bound = Inf, recording_identifier )electrode_burst_duration( data = output_table, time_lower_bound = 0, time_upper_bound = Inf, recording_identifier )
data |
Electrode burst list dataset preprocessed using the create_electrode_dataset function. |
time_lower_bound |
Define lower bound of time interval for which to calculate the MEA parameter (seconds). |
time_upper_bound |
Define upper bound of time interval for which to calculate the MEA parameter (seconds). |
recording_identifier |
Define recording for which to calculate the MEA parameter. Use recording_identifier defined in create_electrode_dataset function. |
An electrode burst list table with three additional columns (mean, SD and SEM burst duration for single electrodes within the specified time interval and recording).
output_MEA_data <- electrode_burst_duration(data = input_MEA_data, time_lower_bound = 0, time_upper_bound = 30, recording_identifier = "burst_recording_1")output_MEA_data <- electrode_burst_duration(data = input_MEA_data, time_lower_bound = 0, time_upper_bound = 30, recording_identifier = "burst_recording_1")
Function reads in electrode burst list data and creates new columns with the mean, SD, and SEM mean ISI within a burst (sec) recorded by single electrodes (within the specified time interval and recording).
electrode_mean_burst_ISI( data = output_table, time_lower_bound = 0, time_upper_bound = Inf, recording_identifier )electrode_mean_burst_ISI( data = output_table, time_lower_bound = 0, time_upper_bound = Inf, recording_identifier )
data |
Electrode burst list dataset preprocessed using the create_electrode_dataset function. |
time_lower_bound |
Define lower bound of time interval for which to calculate the MEA parameter (seconds). |
time_upper_bound |
Define upper bound of time interval for which to calculate the MEA parameter (seconds). |
recording_identifier |
Define recording for which to calculate the MEA parameter. Use recording_identifier defined in create_electrode_dataset function. |
An electrode burst list dataset with three additional columns (mean, SD and SEM mean ISI within a burst (sec) for single electrodes within the specified time interval and recording)
output_MEA_data <- electrode_mean_burst_ISI(data = input_MEA_data, time_lower_bound = 0, time_upper_bound = 30, recording_identifier = "burst_recording_1")output_MEA_data <- electrode_mean_burst_ISI(data = input_MEA_data, time_lower_bound = 0, time_upper_bound = 30, recording_identifier = "burst_recording_1")
Function reads in electrode burst list data and creates new columns with the mean, SD, and SEM number of bursts recorded by single electrodes (within the specified time interval and recording).
electrode_number_of_bursts( data = output_table, time_lower_bound = 0, time_upper_bound = Inf, recording_identifier )electrode_number_of_bursts( data = output_table, time_lower_bound = 0, time_upper_bound = Inf, recording_identifier )
data |
Electrode burst list dataset preprocessed using the create_electrode_dataset function. |
time_lower_bound |
Define lower bound of time interval for which to calculate the MEA parameter (seconds). |
time_upper_bound |
Define upper bound of time interval for which to calculate the MEA parameter (seconds). |
recording_identifier |
Define recording for which to calculate the MEA parameter. Use recording_identifier defined in create_electrode_dataset function. |
An electrode burst list table with three additional columns (mean, SD and SEM number of bursts for single electrodes within the specified time interval and recording).
output_MEA_data <- electrode_number_of_bursts(data = input_MEA_data, time_lower_bound = 0, time_upper_bound = 30, recording_identifier = "burst_recording_1")output_MEA_data <- electrode_number_of_bursts(data = input_MEA_data, time_lower_bound = 0, time_upper_bound = 30, recording_identifier = "burst_recording_1")
Function reads in electrode burst list data and creates new columns with the mean, SD, and SEM number of spikes per burst recorded by single electrodes (within the specified time interval and recording).
electrode_spikes_per_burst( data = output_table, time_lower_bound = 0, time_upper_bound = Inf, recording_identifier )electrode_spikes_per_burst( data = output_table, time_lower_bound = 0, time_upper_bound = Inf, recording_identifier )
data |
Electrode burst list dataset preprocessed using the create_electrode_dataset function. |
time_lower_bound |
Define lower bound of time interval for which to calculate the MEA parameter (seconds). |
time_upper_bound |
Define upper bound of time interval for which to calculate the MEA parameter (seconds). |
recording_identifier |
Define recording for which to calculate the MEA parameter. Use recording_identifier defined in create_electrode_dataset function. |
An electrode burst list table with three additional columns (mean, SD and SEM number of spikes per burst for single electrodes within the specified time interval and recording).
output_MEA_data <- electrode_spikes_per_burst(data = input_MEA_data, time_lower_bound = 0, time_upper_bound = 30, recording_identifier = "burst_recording_1")output_MEA_data <- electrode_spikes_per_burst(data = input_MEA_data, time_lower_bound = 0, time_upper_bound = 30, recording_identifier = "burst_recording_1")
A data set containing electrode burst data with additional columns calculated for various MEA parameters.
input_electrode_barchartinput_electrode_barchart
A data frame with 8886 rows and 58 variables
<https://www.github.com/egordon2/MEAanalysis>
A data set with well average synchrony index data for a baseline and comparison experimental condition.
input_heatmap_datainput_heatmap_data
A data frame with 24 rows and 3 variables
<https://www.github.com/egordon2/MEAanalysis>
A data set containing electrode burst list data filtered and reformated for use in analysis.
input_MEA_datainput_MEA_data
A data frame with 8886 rows and 36variables:
<https://www.github.com/egordon2/MEAanalysis>
A data set containing electrode burst data with additional columns calculated for various MEA parameters.
input_well_barchartinput_well_barchart
A data frame with 8886 rows and 70 variables
<https://www.github.com/egordon2/MEAanalysis>
Function creates a heatmap of the synchrony index for each well grouped by heatmap condition.
MEA_heatmap( data, x_axis_title = "Experimental Condition", well_filter = "A1|A2|A3|A4|A5|A6|B1|B2|B3|B4|B5|B6|C1|C2|C3|C4|C5|C6|D1|D2|D3|D4|D5|D6" )MEA_heatmap( data, x_axis_title = "Experimental Condition", well_filter = "A1|A2|A3|A4|A5|A6|B1|B2|B3|B4|B5|B6|C1|C2|C3|C4|C5|C6|D1|D2|D3|D4|D5|D6" )
data |
Dataset containing well average synchrony index data. |
x_axis_title |
Include title for heatmap x axis. Default is "Experimental Condition" |
well_filter |
Argument can be used to filter for specific MEA wells to include in the heatmap. |
A heatmap of the synchrony index for each well grouped by heatmap condition.
p <- MEA_heatmap(data = input_heatmap_data, x_axis_title = "Experimental Condition", well_filter = "A1|A2|A3|A4|A5|A6|B1|B2|B3|B4|B5|B6|C1|C2|C3|C4|C5|C6|D1|D2|D3|D4|D5|D6")p <- MEA_heatmap(data = input_heatmap_data, x_axis_title = "Experimental Condition", well_filter = "A1|A2|A3|A4|A5|A6|B1|B2|B3|B4|B5|B6|C1|C2|C3|C4|C5|C6|D1|D2|D3|D4|D5|D6")
Function creates a bar chart of calculated MEA parameters by single electrode for a given time interval and recording.
single_electrode_barchart( data = output_table, electrode_parameter, electrode_filter = "A1|A2|A3|A4|A5|A6|B1|B2|B3|B4|B5|B6|C1|C2|C3|C4|C5|C6|D1|D2|D3|D4|D5|D6", statistic = se )single_electrode_barchart( data = output_table, electrode_parameter, electrode_filter = "A1|A2|A3|A4|A5|A6|B1|B2|B3|B4|B5|B6|C1|C2|C3|C4|C5|C6|D1|D2|D3|D4|D5|D6", statistic = se )
data |
Dataset containing electrode burst data and calculated MEA parameter. Use create_electrode_dataset and electrode parameter functions to preprocess data before use in this function (i.e., electrode_burst_duration, electrode_mean_burst_ISI, electrode_number_of_bursts, electrode_spikes_per_burst). |
electrode_parameter |
Include "number_of_bursts"/ "burst_duration"/ "spikes_per_burst"/ "mean_burst_ISI" to determine the parameter visualised in the barchart. |
electrode_filter |
Argument can be used to filter for single electrodes to include in the barchart. |
statistic |
Include "se" or "sd" to determine whether bar chart error bars represent the standard error or standard deviation of the mean. |
A bar chart of calculated MEA parameters by single electrode for a given time interval and recording.
p <- single_electrode_barchart(data = input_electrode_barchart, electrode_parameter = "burst_duration", electrode_filter = "A1_", statistic = se) p <- single_electrode_barchart(data = input_electrode_barchart, electrode_parameter = "spikes_per_burst", electrode_filter = "A1_", statistic = se) p <- single_electrode_barchart(data = input_electrode_barchart, electrode_parameter = "mean_burst_ISI", electrode_filter = "A1_", statistic = se) p <- single_electrode_barchart(data = input_electrode_barchart, electrode_parameter = "number_of_bursts", electrode_filter = "A1_")p <- single_electrode_barchart(data = input_electrode_barchart, electrode_parameter = "burst_duration", electrode_filter = "A1_", statistic = se) p <- single_electrode_barchart(data = input_electrode_barchart, electrode_parameter = "spikes_per_burst", electrode_filter = "A1_", statistic = se) p <- single_electrode_barchart(data = input_electrode_barchart, electrode_parameter = "mean_burst_ISI", electrode_filter = "A1_", statistic = se) p <- single_electrode_barchart(data = input_electrode_barchart, electrode_parameter = "number_of_bursts", electrode_filter = "A1_")
Function creates a bar chart of calculated MEA parameters by well for a given time interval and recording.
well_barchart( data = output_table, well_parameter, well_filter = "A1|A2|A3|A4|A5|A6|B1|B2|B3|B4|B5|B6|C1|C2|C3|C4|C5|C6|D1|D2|D3|D4|D5|D6", statistic = se )well_barchart( data = output_table, well_parameter, well_filter = "A1|A2|A3|A4|A5|A6|B1|B2|B3|B4|B5|B6|C1|C2|C3|C4|C5|C6|D1|D2|D3|D4|D5|D6", statistic = se )
data |
Dataset containing electrode burst data and calculated MEA parameter. Use create_electrode_dataset and well parameter functions to preprocess data before use in this function (i.e., well_burst_duration, well_mean_burst_ISI, well_number_of_bursts, well_spikes_per_burst). |
well_parameter |
Include "number_of_bursts"/ "burst_duration"/ "spikes_per_burst"/ "mean_burst_ISI" to determine the parameter visualised in the barchart. |
well_filter |
Argument can be used to filter for specific MEA wells to include in the barchart. |
statistic |
Include "se" or "sd" to determine whether bar chart error bars represent the standard error or standard deviation of the mean. |
A bar chart of calculated MEA parameters by single electrode for a given time interval and recording.
p <- well_barchart(data = input_well_barchart, well_parameter = "burst_duration", well_filter = "A1|A2|A3|A4", statistic = se) p <- well_barchart(data = input_well_barchart, well_parameter = "spikes_per_burst", well_filter = "A1|A2|A3|A4", statistic = se) p <- well_barchart(data = input_well_barchart, well_parameter = "mean_burst_ISI", well_filter = "A1|A2|A3|A4", statistic = se) p <- well_barchart(data = input_well_barchart, well_parameter = "number_of_bursts", well_filter = "A1|A2|A3|A4", statistic = se)p <- well_barchart(data = input_well_barchart, well_parameter = "burst_duration", well_filter = "A1|A2|A3|A4", statistic = se) p <- well_barchart(data = input_well_barchart, well_parameter = "spikes_per_burst", well_filter = "A1|A2|A3|A4", statistic = se) p <- well_barchart(data = input_well_barchart, well_parameter = "mean_burst_ISI", well_filter = "A1|A2|A3|A4", statistic = se) p <- well_barchart(data = input_well_barchart, well_parameter = "number_of_bursts", well_filter = "A1|A2|A3|A4", statistic = se)
Function reads in electrode burst list data and creates new columns with the mean, SD, and SEM burst duration recorded for each well (within the specified time interval and recording).
well_burst_duration( data = output_table, time_lower_bound = 0, time_upper_bound = Inf, recording_identifier )well_burst_duration( data = output_table, time_lower_bound = 0, time_upper_bound = Inf, recording_identifier )
data |
Electrode burst list dataset preprocessed using the create_electrode_dataset function. |
time_lower_bound |
Define lower bound of time interval for which to calculate the MEA parameter (seconds). |
time_upper_bound |
Define upper bound of time interval for which to calculate the MEA parameter (seconds). |
recording_identifier |
Define recording for which to calculate the MEA parameter. Use recording_identifier defined in create_electrode_dataset function. |
An electrode burst list table with three additional columns (mean, SD and SEM burst duration recorded for each well within the specified time interval and recording).
output_MEA_data <- well_burst_duration(data = input_MEA_data, time_lower_bound = 0, time_upper_bound = 30, recording_identifier = "burst_recording_1")output_MEA_data <- well_burst_duration(data = input_MEA_data, time_lower_bound = 0, time_upper_bound = 30, recording_identifier = "burst_recording_1")
Function reads in electrode burst list data and creates new columns with the mean, SD, and SEM mean ISI within a burst (sec) recorded for each well (within the specified time interval and recording).
well_mean_burst_ISI( data = output_table, time_lower_bound = 0, time_upper_bound = Inf, recording_identifier )well_mean_burst_ISI( data = output_table, time_lower_bound = 0, time_upper_bound = Inf, recording_identifier )
data |
Electrode burst list dataset preprocessed using the create_electrode_dataset function. |
time_lower_bound |
Define lower bound of time interval for which to calculate the MEA parameter (seconds). |
time_upper_bound |
Define upper bound of time interval for which to calculate the MEA parameter (seconds). |
recording_identifier |
Define recording for which to calculate the MEA parameter. Use recording_identifier defined in create_electrode_dataset function. |
An electrode burst list table with three additional columns (mean, SD and SEM mean ISI within a burst (sec) recorded for each well within the specified time interval and recording).
output_MEA_data <- well_mean_burst_ISI(data = input_MEA_data, time_lower_bound = 0, time_upper_bound = 30, recording_identifier = "burst_recording_1")output_MEA_data <- well_mean_burst_ISI(data = input_MEA_data, time_lower_bound = 0, time_upper_bound = 30, recording_identifier = "burst_recording_1")
Function reads in electrode burst list data and creates new columns with the mean, SD, and SEM number of bursts recorded for each well (within the specified time interval and recording).
well_number_of_bursts( data = output_table, time_lower_bound = 0, time_upper_bound = Inf, recording_identifier )well_number_of_bursts( data = output_table, time_lower_bound = 0, time_upper_bound = Inf, recording_identifier )
data |
Electrode burst list dataset preprocessed using the create_electrode_dataset function. |
time_lower_bound |
Define lower bound of time interval for which to calculate the MEA parameter (seconds). |
time_upper_bound |
Define upper bound of time interval for which to calculate the MEA parameter (seconds). |
recording_identifier |
Define recording for which to calculate the MEA parameter. Use recording_identifier defined in create_electrode_dataset function. |
An electrode burst list table with three additional columns (mean, SD and SEM number of bursts recorded for each well within the specified time interval and recording).
output_MEA_data <- well_number_of_bursts(data = input_MEA_data, time_lower_bound = 0, time_upper_bound = 30, recording_identifier = "burst_recording_1")output_MEA_data <- well_number_of_bursts(data = input_MEA_data, time_lower_bound = 0, time_upper_bound = 30, recording_identifier = "burst_recording_1")
Function reads in electrode burst list data and creates new columns with the mean, SD, and SEM number of spikes per burst recorded for each well (within the specified time interval and recording).
well_spikes_per_burst( data = output_table, time_lower_bound = 0, time_upper_bound = Inf, recording_identifier )well_spikes_per_burst( data = output_table, time_lower_bound = 0, time_upper_bound = Inf, recording_identifier )
data |
Electrode burst list dataset preprocessed using the create_electrode_dataset function. |
time_lower_bound |
Define lower bound of time interval for which to calculate the MEA parameter (seconds). |
time_upper_bound |
Define upper bound of time interval for which to calculate the MEA parameter (seconds). |
recording_identifier |
Define recording for which to calculate the MEA parameter. Use recording_identifier defined in create_electrode_dataset function. |
An electrode burst list table with three additional columns (mean, SD and SEM number of spikes per burst recorded for each well within the specified time interval and recording).
output_MEA_data <- well_spikes_per_burst(data = input_MEA_data, time_lower_bound = 0, time_upper_bound = 30, recording_identifier = "burst_recording_1")output_MEA_data <- well_spikes_per_burst(data = input_MEA_data, time_lower_bound = 0, time_upper_bound = 30, recording_identifier = "burst_recording_1")